import request from '@/utils/request'

// 查询活动数据列表
export function activityList(data) {
  return request({
    url: '/activity/list',
    method: 'post',
    data: {
      id: data.id,
      activityTitle: data.activityTitle,
      pageNum: data.pageNum,
      pageSize: data.pageSize
    }
  })
}

// 添加活动
export function addActivity(data) {
  return request({
    url: '/activity/add',
    method: 'post',
    data: {
      activityTitle: data.activityTitle,
      activityCarouselImg: data.activityCarouselImg, // 轮播图
      activityContent: data.activityContent, // 活动内容详细
      contentImg: data.contentImg, // 活动内容配图
      signUpMax: data.signUpMax, //  活动人数上限
      registrationEndTime: data.registrationEndTime, // 报名活动结束时间
      sort: data.sort, // 权重
      status: data.status, // 状态 0 是已作废 1 是已发布   2 是草稿 3 是已修改
      radio: data.radio // 是否需要二维码1需要，2不需要
    }
  })
}

// 修改活动
export function updateActivity(data) {
  return request({
    url: '/activity/update',
    method: 'put',
    data: {
      signInCode: data.signInCode,
      id: data.id,
      activityTitle: data.activityTitle,
      activityCarouselImg: data.activityCarouselImg, // 轮播图
      activityContent: data.activityContent, // 活动内容详细
      contentImg: data.contentImg, // 活动内容配图
      signUpMax: data.signUpMax, //  活动人数上限
      registrationEndTime: data.registrationEndTime, // 报名活动结束时间
      sort: data.sort, // 权重
      status: data.status, // 状态 0 是已作废 1 是已发布   2 是草稿 3 是已修改
      radio: data.signInCode
    }
  })
}

// 查询 活动详情
export function activityById(id) {
  return request({
    url: '/activity/' + id,
    method: 'get'
  })
}

// 批量活动作废
export function invalidActivity(data) {
  return request({
    url: '/activity/invalid',
    method: 'put',
    data
  })
}

// 查询活动报名人
export function getSignUp(data) {
  return request({
    url: '/signUp',
    method: 'post',
    data: {
      id: data.id,
      userName: data.userName,
      phone: data.phone,
      pageNum: data.pageNum,
      pageSize: data.pageSize
    }
  })
}

// 删除活动报名人
export function deleteSignUp(data) {
  console.log(data)
  return request({
    url: '/signUp/' + data.deleteId,
    method: 'delete',
    data: {
      sendSMS: data.sendSMS
    }
  })
}

// 根据活动id 获取所有签到人员列表
export function getActivitySignIn(data) {
  return request({
    url: '/activity/signIn/' + data.activityId,
    method: 'get',
    params: {
      userName: data.userName,
      userTel: data.userTel,
      pageNum: data.pageNum,
      pageSize: data.pageSize
    }
  })
}

